==> haskell-mono-traversable-instances-0.1.1.0-356-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-xN68RoitIXDRRQsBEIoxG
key:                  mono-traversable-instances-0.1.1.0-xN68RoitIXDRRQsBEIoxG
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  a5d30773af5e2be753fcd7e3ecaf6e5b
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-xN68RoitIXDRRQsBEIoxG
depends:
    base-4.17.2.1 comonad-5.0.9-FIUuIsgkoVrC4nmIsOTMUJ containers-0.6.7
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    dlist-instances-0.1.1.1-1PF5b6vAvpMH0LL2Cykwfs
    mono-traversable-1.0.21.0-JvH5BMFrsZxIHRwZxLqPsO
    semigroupoids-6.0.1-DVEuzF5juim9cWw2u8IF1A transformers-0.5.6.2
    vector-instances-3.4.3-BQk6Pj4EMrX21HB23BSc6

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-instances-0.1.1.0-357-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-5f7EBcARqty2u6gp5NbBcg
key:                  mono-traversable-instances-0.1.1.0-5f7EBcARqty2u6gp5NbBcg
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  01c5cd51e9e03f543f52f0d09f7f3cdb
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-5f7EBcARqty2u6gp5NbBcg
depends:
    base-4.17.2.1 comonad-5.0.9-DQaTWlknK4SF1nm84xsjc7 containers-0.6.7
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    dlist-instances-0.1.1.1-1PF5b6vAvpMH0LL2Cykwfs
    mono-traversable-1.0.21.0-EiGDTabxPak953bwJELl0b
    semigroupoids-6.0.1-DiRpiGMVw5R87vPlhF19iO transformers-0.5.6.2
    vector-instances-3.4.3-LPXBzWALtIe6j3VlzsSLC5

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
